@@ -355,6 +355,25 @@ class KubeSpawner(Spawner):
         """
     )
 
+    pod_connect_ip = Unicode(
+        config=True,
+        help="""
+        The IP address (or hostname) of user's pods which KubeSpawner connects to.
+        If you do not specify the value, KubeSpawner will use the pod IP.
+
+        e.g. 'jupyter-{username}--{servername}.notebooks.jupyterhub.svc.cluster.local',
+
+        `{username}` is expanded to the escaped, dns-label-safe username.
+        `{servername}` is expanded to the escaped, dns-label-safe server name, if any.
+
+        Trailing `-` characters in each domain level are stripped for safe handling of empty server names (user default servers).
+
+        This must be unique within the namespace the pods are being spawned
+        in, so if you are running multiple jupyterhubs spawning in the
+        same namespace, consider setting this to be something more unique.
+        """
+    )
+
     storage_pvc_ensure = Bool(
         False,
         config=True,
@@ -567,6 +586,7 @@ class KubeSpawner(Spawner):
             Integer(),
             Callable(),
         ],
+        default_value=None,
         allow_none=True,
         config=True,
         help="""
@@ -592,6 +612,7 @@ class KubeSpawner(Spawner):
             Integer(),
             Callable(),
         ],
+        default_value=None,
         allow_none=True,
         config=True,
         help="""
@@ -617,6 +638,7 @@ class KubeSpawner(Spawner):
             Integer(),
             Callable(),
         ],
+        default_value=None,
         allow_none=True,
         config=True,
         help="""
@@ -681,6 +703,20 @@ class KubeSpawner(Spawner):
         """
     )
 
+    allow_privilege_escalation = Bool(
+        True,
+        config=True,
+        help="""
+        Controls whether a process can gain more privileges than its parent process.
+        
+        This bool directly controls whether the no_new_privs flag gets set on the container 
+        process.
+
+        AllowPrivilegeEscalation is true always when the container is: 
+        1) run as Privileged OR 2) has CAP_SYS_ADMIN.
+        """
+    )
+
     modify_pod_hook = Callable(
         None,
         allow_none=True,
@@ -840,6 +876,8 @@ class KubeSpawner(Spawner):
         For example to match the Nodes that have a label of `content: jupyter` use::
 
            c.KubeSpawner.storage_selector = {'matchLabels':{'content': 'jupyter'}}
+
+        `{username}` is expanded to the escaped, dns-label safe username.
         """
     )
 
@@ -1119,13 +1157,6 @@ class KubeSpawner(Spawner):
 
     profile_form_template = Unicode(
         """
-        <script>
-        // JupyterHub 0.8 applied form-control indisciminately to all form elements.
-        // Can be removed once we stop supporting JupyterHub 0.8
-        $(document).ready(function() {
-            $('#kubespawner-profiles-list input[type="radio"]').removeClass('form-control');
-        });
-        </script>
         <style>
         /* The profile description should not be bold, even though it is inside the <label> tag */
         #kubespawner-profiles-list label p {
@@ -1278,6 +1309,7 @@ class KubeSpawner(Spawner):
         "singleuser_fs_gid",
         "singleuser_supplemental_gids",
         "singleuser_privileged",
+        "singleuser_allow_privilege_escalation"
         "singleuser_lifecycle_hooks",
         "singleuser_extra_pod_config",
         "singleuser_init_containers",
@@ -1484,6 +1516,7 @@ class KubeSpawner(Spawner):
             fs_gid=fs_gid,
             supplemental_gids=supplemental_gids,
             run_privileged=self.privileged,
+            allow_privilege_escalation=self.allow_privilege_escalation,
             env=self.get_env(),
             volumes=self._expand_all(self.volumes),
             volume_mounts=self._expand_all(self.volume_mounts),
@@ -1525,11 +1558,13 @@ class KubeSpawner(Spawner):
 
         annotations = self._build_common_annotations({})
 
+        storage_selector = self._expand_all(self.storage_selector)
+
         return make_pvc(
             name=self.pvc_name,
             storage_class=self.storage_class,
             access_modes=self.storage_access_modes,
-            selector=self.storage_selector,
+            selector=storage_selector,
             storage=self.storage_capacity,
             labels=labels,
             annotations=annotations
@@ -1607,7 +1642,7 @@ class KubeSpawner(Spawner):
         """
         # have to wait for first load of data before we have a valid answer
         if not self.pod_reflector.first_load_future.done():
-            await self.pod_reflector.first_load_future
+            await asyncio.wrap_future(self.pod_reflector.first_load_future)
         data = self.pod_reflector.pods.get(self.pod_name, None)
         if data is not None:
             if data["status"]["phase"] == 'Pending':
@@ -1943,7 +1978,14 @@ class KubeSpawner(Spawner):
                     ]
                 ),
             )
-        return (pod["status"]["podIP"], self.port)
+
+        if self.pod_connect_ip:
+            # Strip trailing `-` of empty server names in each domain level.
+            ip = ".".join([s.rstrip("-") for s in self._expand_user_properties(self.pod_connect_ip).split(".")])
+        else:
+            ip = pod["status"]["podIP"]
+
+        return (ip, self.port)
 
     async def _make_delete_pod_request(self, pod_name, delete_options, grace_seconds, request_timeout):
         """
